@@ -13,12 +13,14 @@ def create_refill(instance):
             - instance.subject_visit.appointment.appt_datetime
         ).days
     RefillCreator(
-        subject_identifier=instance.subject_visit.subject_identifier,
-        refill_date=instance.refill_date,
-        visit_code=instance.subject_visit.appointment.visit_code,
-        visit_code_sequence=instance.subject_visit.appointment.visit_code_sequence,
-        number_of_days=number_of_days,
         dosage_guideline=instance.dosage_guideline,
         formulation=instance.formulation,
         make_active=True,
+        number_of_days=number_of_days,
+        refill_date=instance.refill_date,
+        roundup_divisible_by=instance.roundup_divisible_by,
+        subject_identifier=instance.subject_visit.subject_identifier,
+        visit_code=instance.subject_visit.appointment.visit_code,
+        visit_code_sequence=instance.subject_visit.appointment.visit_code_sequence,
+        weight_in_kgs=getattr(instance, "weight_in_kgs", None),
     )
